@@ -1,5 +1,7 @@
 from .config import BaseBridgeConfig
-from .custom_puppet import CustomPuppetMixin, CustomPuppetError, OnlyLoginSelf, InvalidAccessToken
+from .custom_puppet import (CustomPuppetMixin, CustomPuppetError, OnlyLoginSelf,
+                            InvalidAccessToken, AutologinError, OnlyLoginTrustedDomain,
+                            HomeserverURLNotFound)
 from .matrix import BaseMatrixHandler
 from .portal import BasePortal
 from .user import BaseUser
@@ -7,4 +9,4 @@ from .puppet import BasePuppet
 from .bridge import Bridge
 from .notification_disabler import NotificationDisabler
 from .async_getter_lock import async_getter_lock
-from .state import BridgeState
+from mautrix.util.bridge_state import BridgeState
