@@ -55,6 +55,8 @@ class BaseBridgeConfig(BaseFileConfig, BaseValidatableConfig, ABC):
         copy("homeserver.address")
         copy("homeserver.domain")
         copy("homeserver.verify_ssl")
+        copy("homeserver.http_retry_count")
+        copy("homeserver.status_endpoint")
 
         copy("appservice.address")
         copy("appservice.hostname")
