@@ -31,7 +31,7 @@ except ImportError:
     Database = None
 
 if TYPE_CHECKING:
-    from mautrix.bridge import Bridge
+    from mautrix.util.bridge_state import Bridge
 
 
 class EncryptionManager:
@@ -49,7 +49,6 @@ class EncryptionManager:
     _id_prefix: str
     _id_suffix: str
 
-    sync_task: asyncio.Future
     _share_session_events: Dict[RoomID, asyncio.Event]
 
     def __init__(self, bridge: 'Bridge', homeserver_address: str, user_id_prefix: str,
@@ -161,11 +160,12 @@ class EncryptionManager:
         except SessionNotFound as e:
             if not wait_session_timeout:
                 raise
-            self.log.debug(f"Didn't find session {e.session_id},"
-                           f" waiting {wait_session_timeout} seconds for session to arrive")
+            self.log.debug(f"Couldn't find session {e.session_id} trying to decrypt {evt.event_id},"
+                           f" waiting {wait_session_timeout} seconds...")
             got_keys = await self.crypto.wait_for_session(evt.room_id, e.sender_key, e.session_id,
                                                           timeout=wait_session_timeout)
             if got_keys:
+                self.log.debug(f"Got session {e.session_id} after waiting, trying to decrypt {evt.event_id} again")
                 decrypted = await self.crypto.decrypt_megolm_event(evt)
             else:
                 raise
@@ -193,11 +193,11 @@ class EncryptionManager:
         if not device_id:
             await self.crypto_store.put_device_id(self.client.device_id)
             self.log.debug(f"Logged in with new device ID {self.client.device_id}")
-        self.sync_task = self.client.start(self._filter)
+        _ = self.client.start(self._filter)
         self.log.info("End-to-bridge encryption support is enabled")
 
     async def stop(self) -> None:
-        self.sync_task.cancel()
+        self.client.stop()
         await self.crypto_store.close()
         if self.crypto_db:
             await self.crypto_db.stop()
