@@ -3,7 +3,8 @@
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
-from typing import TYPE_CHECKING
+from typing import Dict, Any, TYPE_CHECKING
+from collections import defaultdict
 from abc import ABC, abstractmethod
 import asyncio
 import logging
@@ -20,6 +21,7 @@ if TYPE_CHECKING:
 
 class BasePuppet(CustomPuppetMixin, ABC):
     log: TraceLogger = logging.getLogger("mau.puppet")
+    _async_get_locks: Dict[Any, asyncio.Lock] = defaultdict(lambda: asyncio.Lock())
     az: AppService
     loop: asyncio.AbstractEventLoop
     mx: 'BaseMatrixHandler'
