@@ -15,9 +15,10 @@ from mautrix.types import UserID, RoomID, EventType, Membership
 from mautrix.errors import MNotFound
 from mautrix.util.logging import TraceLogger
 from mautrix.util.opt_prometheus import Gauge
+from mautrix.util.bridge_state import BridgeState, BridgeStateEvent
 
 from .portal import BasePortal
-from .state import BridgeState
+from .puppet import BasePuppet
 
 if TYPE_CHECKING:
     from .bridge import Bridge
@@ -52,6 +53,9 @@ class BaseUser(ABC):
     async def is_logged_in(self) -> bool:
         raise NotImplementedError()
 
+    async def get_puppet(self) -> Optional['BasePuppet']:
+        raise NotImplementedError()
+
     async def is_in_portal(self, portal: BasePortal) -> bool:
         try:
             member_event = await portal.main_intent.get_state_event(
@@ -110,12 +114,24 @@ class BaseUser(ABC):
                 metric.dec(1)
             self._metric_value[metric] = value
 
+    async def fill_bridge_state(self, state: BridgeState) -> None:
+        state.user_id = self.mxid
+        state.fill()
+
     async def get_bridge_state(self) -> BridgeState:
         raise NotImplementedError()
 
-    async def push_bridge_state(self, ok: bool, error: Optional[str] = None,
-                                message: Optional[str] = None, ttl: Optional[int] = None) -> None:
-        state = BridgeState(user_id=self.mxid, ok=ok, error=error, message=message, ttl=ttl).fill()
+    async def push_bridge_state(self, state_event: BridgeStateEvent, error: Optional[str] = None,
+                                message: Optional[str] = None, ttl: Optional[int] = None,
+                                remote_id: Optional[str] = None) -> None:
+        state = BridgeState(
+            state_event=state_event,
+            error=error,
+            message=message,
+            ttl=ttl,
+            remote_id=remote_id,
+        )
+        await self.fill_bridge_state(state)
         if state.should_deduplicate(self._prev_bridge_status):
             return
         self._prev_bridge_status = state
