@@ -13,8 +13,17 @@ from .primitive import RoomID, RoomAlias, SyncToken, ContentURI, UserID
 from .util import SerializableAttrs
 from .event import Event
 
-DeviceLists = NamedTuple("DeviceLists", changed=List[UserID], left=List[UserID])
-DeviceOTKCount = NamedTuple("DeviceOTKCount", curve25519=int, signed_curve25519=int)
+
+@dataclass
+class DeviceLists(SerializableAttrs):
+    changed: List[UserID] = attr.ib(factory=lambda: [])
+    left: List[UserID] = attr.ib(factory=lambda: [])
+
+
+@dataclass
+class DeviceOTKCount(SerializableAttrs):
+    curve25519: int
+    signed_curve25519: int
 
 
 class RoomCreatePreset(Enum):
@@ -52,7 +61,7 @@ class PaginationDirection(Enum):
 
 
 @dataclass
-class RoomAliasInfo(SerializableAttrs['RoomAliasInfo']):
+class RoomAliasInfo(SerializableAttrs):
     """
     Room alias query result, as specified in the `alias resolve endpoint`_
 
@@ -71,7 +80,7 @@ DirectoryPaginationToken = NewType("DirectoryPaginationToken", str)
 
 
 @dataclass
-class PublicRoomInfo(SerializableAttrs['PublicRoomInfo']):
+class PublicRoomInfo(SerializableAttrs):
     room_id: RoomID
 
     num_joined_members: int
@@ -88,7 +97,7 @@ class PublicRoomInfo(SerializableAttrs['PublicRoomInfo']):
 
 
 @dataclass
-class RoomDirectoryResponse(SerializableAttrs['RoomDirectoryResponse']):
+class RoomDirectoryResponse(SerializableAttrs):
     chunk: List[PublicRoomInfo]
     next_batch: DirectoryPaginationToken = None
     prev_batch: DirectoryPaginationToken = None
@@ -100,6 +109,6 @@ PaginatedMessages = NamedTuple("PaginatedMessages", start=SyncToken, end=SyncTok
 
 
 @dataclass
-class VersionsResponse(SerializableAttrs['VersionsResponse']):
+class VersionsResponse(SerializableAttrs):
     versions: List[str]
     unstable_features: Dict[str, bool] = attr.ib(factory=lambda: {})
