@@ -1,18 +1,18 @@
-# Copyright (c) 2020 Tulir Asokan
+# Copyright (c) 2021 Tulir Asokan
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
-from typing import Dict, Type, TypeVar, Any, Union, Optional, Tuple, Iterator, Callable, NewType
+from typing import (Dict, Type, TypeVar, Any, Union, Optional, Tuple, Iterator, Callable, NewType,
+                    Generic)
 from uuid import UUID
 import logging
 import attr
 import copy
-import sys
 
 from ..primitive import JSON
 from .serializable import (SerializerError, UnknownSerializationError, Serializable,
-                           GenericSerializable)
+                           AbstractSerializable, SerializableSubtype)
 from .obj import Obj, Lst
 
 T = TypeVar("T")
@@ -27,10 +27,66 @@ deserializer_map: Dict[Type[T], Deserializer] = {
     UUID: UUID,
 }
 
-no_value = object()
+META_JSON = "json"
+META_FLATTEN = "flatten"
+META_HIDDEN = "hidden"
+META_IGNORE_ERRORS = "ignore_errors"
+META_OMIT_EMPTY = "omitempty"
+META_OMIT_DEFAULT = "omitdefault"
+
 log = logging.getLogger("mau.attrs")
 
 
+def field(default: Any = attr.NOTHING, factory: Optional[Callable[[], Any]] = None,
+          json: Optional[str] = None, flatten: bool = False, hidden: bool = False,
+          ignore_errors: bool = False, omit_empty: bool = True, omit_default: bool = False,
+          metadata: Optional[Dict[str, Any]] = None, **kwargs):
+    """
+    A wrapper around :meth:`attr.ib` to conveniently add SerializableAttrs metadata fields.
+
+    Args:
+        default: Same as attr.ib, the default value for the field.
+        factory: Same as attr.ib, a factory function that creates the default value.
+        json: The JSON key used for de/serializing the object.
+        flatten: Set to flatten subfields inside this field to be a part of the parent object in
+            serialized objects. When deserializing, the input data will be deserialized into both
+            the parent and child fields, so the classes should ignore unknown keys.
+        hidden: Set to always omit the key from serialized objects.
+        ignore_errors: Set to ignore type errors while deserializing.
+        omit_empty: Set to omit the key from serialized objects if the value is ``None``.
+        omit_default: Set to omit the key from serialized objects if the value is equal to the
+            default.
+        metadata: Additional metadata for attr.ib.
+        **kwargs: Additional keyword arguments for attr.ib.
+
+    Returns:
+        The decorator function returned by attr.ib.
+
+    Examples:
+        >>> from attr import dataclass
+        >>> from mautrix.types import SerializableAttrs, field
+        >>> @dataclass
+        ... class SomeData(SerializableAttrs):
+        ...     my_field: str = field(json="com.example.namespaced_field", default="hi")
+        ...
+        >>> SomeData().serialize()
+        {'com.example.namespaced_field': 'hi'}
+        >>> SomeData.deserialize({"com.example.namespaced_field": "hmm"})
+        SomeData(my_field='hmm')
+    """
+    custom_meta = {
+        META_JSON: json,
+        META_FLATTEN: flatten,
+        META_HIDDEN: hidden,
+        META_IGNORE_ERRORS: ignore_errors,
+        META_OMIT_EMPTY: omit_empty,
+        META_OMIT_DEFAULT: omit_default,
+    }
+    metadata = metadata or {}
+    metadata.update({k: v for k, v in custom_meta.items() if v is not None})
+    return attr.ib(default=default, factory=factory, metadata=metadata, **kwargs)
+
+
 def serializer(elem_type: Type[T]) -> Callable[[Serializer], Serializer]:
     """
     Define a custom serialization function for the given type.
@@ -39,7 +95,8 @@ def serializer(elem_type: Type[T]) -> Callable[[Serializer], Serializer]:
         elem_type: The type to define the serializer for.
 
     Returns:
-        Decorator for the function.
+        Decorator for the function. The decorator will simply add the function to a map of
+        deserializers and return the function.
 
     Examples:
         >>> from datetime import datetime
@@ -64,7 +121,8 @@ def deserializer(elem_type: Type[T]) -> Callable[[Deserializer], Deserializer]:
         elem_type: The type hint to define the deserializer for.
 
     Returns:
-        Decorator for the function:
+        Decorator for the function. The decorator will simply add the function to a map of
+        deserializers and return the function.
 
     Examples:
         >>> from datetime import datetime
@@ -82,12 +140,14 @@ def deserializer(elem_type: Type[T]) -> Callable[[Deserializer], Deserializer]:
 
 
 def _fields(attrs_type: Type[T], only_if_flatten: bool = None) -> Iterator[Tuple[str, Type[T2]]]:
-    return ((field.metadata.get("json", field.name), field) for field in attr.fields(attrs_type)
-            if only_if_flatten is None or field.metadata.get("flatten", False) == only_if_flatten
-            and not field.metadata.get("hidden", False))
+    for field in attr.fields(attrs_type):
+        if field.metadata.get(META_HIDDEN, False):
+            continue
+        if only_if_flatten is None or field.metadata.get(META_FLATTEN, False) == only_if_flatten:
+            yield field.metadata.get(META_JSON, field.name), field
 
 
-immutable = (int, str, float, bool, type(None))
+immutable = int, str, float, bool, type(None)
 
 
 def _safe_default(val: T) -> T:
@@ -95,6 +155,12 @@ def _safe_default(val: T) -> T:
         return val
     elif val is attr.NOTHING:
         return None
+    elif isinstance(val, attr.Factory):
+        if val.takes_self:
+            # TODO implement?
+            return None
+        else:
+            return val.factory()
     return copy.copy(val)
 
 
@@ -102,9 +168,7 @@ def _dict_to_attrs(attrs_type: Type[T], data: JSON, default: Optional[T] = None,
                    default_if_empty: bool = False) -> T:
     data = data or {}
     unrecognized = {}
-    new_items = {field.name.lstrip("_"):
-                     _try_deserialize(field.type, data, field.default,
-                                      field.metadata.get("ignore_errors", False))
+    new_items = {field.name.lstrip("_"): _try_deserialize(field, data)
                  for _, field in _fields(attrs_type, only_if_flatten=True)}
     fields = dict(_fields(attrs_type, only_if_flatten=False))
     for key, value in data.items():
@@ -115,8 +179,7 @@ def _dict_to_attrs(attrs_type: Type[T], data: JSON, default: Optional[T] = None,
             continue
         name = field.name.lstrip("_")
         try:
-            new_items[name] = _try_deserialize(field.type, value, field.default,
-                                               field.metadata.get("ignore_errors", False))
+            new_items[name] = _try_deserialize(field, value)
         except UnknownSerializationError as e:
             raise SerializerError(f"Failed to deserialize {value} into "
                                   f"key {name} of {attrs_type.__name__}") from e
@@ -131,7 +194,7 @@ def _dict_to_attrs(attrs_type: Type[T], data: JSON, default: Optional[T] = None,
         obj = attrs_type(**new_items)
     except TypeError as e:
         for key, field in _fields(attrs_type):
-            json_key = field.metadata.get("json", key)
+            json_key = field.metadata.get(META_JSON, key)
             if field.default is attr.NOTHING and json_key not in new_items:
                 log.debug("Failed to deserialize %s into %s", data, attrs_type.__name__)
                 raise SerializerError("Missing value for required key "
@@ -142,15 +205,14 @@ def _dict_to_attrs(attrs_type: Type[T], data: JSON, default: Optional[T] = None,
     return obj
 
 
-def _try_deserialize(cls: Type[T], value: JSON, default: Optional[T] = None,
-                     ignore_errors: bool = False) -> T:
+def _try_deserialize(field, value: JSON) -> T:
     try:
-        return _deserialize(cls, value, default)
+        return _deserialize(field.type, value, field.default)
     except SerializerError:
-        if not ignore_errors:
+        if not field.metadata.get(META_IGNORE_ERRORS, False):
             raise
     except (TypeError, ValueError, KeyError) as e:
-        if not ignore_errors:
+        if not field.metadata.get(META_IGNORE_ERRORS, False):
             raise UnknownSerializationError() from e
 
 
@@ -179,22 +241,22 @@ def _deserialize(cls: Type[T], value: JSON, default: Optional[T] = None) -> T:
             pass
         else:
             return deser(value)
+
     if attr.has(cls):
         if _has_custom_deserializer(cls):
             return cls.deserialize(value)
         return _dict_to_attrs(cls, value, default, default_if_empty=True)
     elif cls == Any or cls == JSON:
         return value
-    elif getattr(cls, "__origin__", None) is Union:
-        if len(cls.__args__) == 2 and isinstance(None, cls.__args__[1]):
-            return _deserialize(cls.__args__[0], value, default)
-    elif isinstance(cls, type):
-        if issubclass(cls, Serializable):
-            return cls.deserialize(value)
+    elif isinstance(cls, type) and issubclass(cls, Serializable):
+        return cls.deserialize(value)
 
-    type_class = _get_type_class(cls)
+    type_class = getattr(cls, "__origin__", None)
     args = getattr(cls, "__args__", None)
-    if type_class == list:
+    if type_class is Union:
+        if len(args) == 2 and isinstance(None, args[1]):
+            return _deserialize(args[0], value, default)
+    elif type_class == list:
         item_cls, = args
         return [_deserialize(item_cls, item) for item in value]
     elif type_class == set:
@@ -212,20 +274,6 @@ def _deserialize(cls: Type[T], value: JSON, default: Optional[T] = None) -> T:
     return value
 
 
-if sys.version_info >= (3, 7):
-    def _get_type_class(typ):
-        try:
-            return typ.__origin__
-        except AttributeError:
-            return None
-else:
-    def _get_type_class(typ):
-        try:
-            return typ.__extra__
-        except AttributeError:
-            return None
-
-
 def _actual_type(cls: Type[T]) -> Type[T]:
     if cls is None:
         return cls
@@ -235,27 +283,36 @@ def _actual_type(cls: Type[T]) -> Type[T]:
     return cls
 
 
+def _get_serializer(cls: Type[T]) -> Serializer:
+    return serializer_map.get(_actual_type(cls), _serialize)
+
+
+def _serialize_attrs_field(data: T, field: T2) -> JSON:
+    field_val = getattr(data, field.name)
+    if field_val is None:
+        if not field.metadata.get(META_OMIT_EMPTY, True):
+            if field.default is not attr.NOTHING:
+                field_val = _safe_default(field.default)
+        else:
+            return attr.NOTHING
+
+    if field.metadata.get(META_OMIT_DEFAULT, False) and field_val == field.default:
+        return attr.NOTHING
+
+    return _get_serializer(field.type)(field_val)
+
+
 def _attrs_to_dict(data: T) -> JSON:
     new_dict = {}
     for json_name, field in _fields(data.__class__):
         if not json_name:
             continue
-        field_val = getattr(data, field.name)
-        if field_val is None:
-            if not field.metadata.get("omitempty", True):
-                field_val = field.default
+        serialized = _serialize_attrs_field(data, field)
+        if serialized is not attr.NOTHING:
+            if field.metadata.get(META_FLATTEN, False) and isinstance(serialized, dict):
+                new_dict.update(serialized)
             else:
-                continue
-        if field.metadata.get("omitdefault", False) and field_val == field.default:
-            continue
-        try:
-            serialized = serializer_map[_actual_type(field.type)](field_val)
-        except KeyError:
-            serialized = _serialize(field_val)
-        if field.metadata.get("flatten", False) and isinstance(serialized, dict):
-            new_dict.update(serialized)
-        elif serialized != no_value:
-            new_dict[json_name] = serialized
+                new_dict[json_name] = serialized
     try:
         new_dict.update(data.unrecognized_)
     except (AttributeError, TypeError):
@@ -275,7 +332,8 @@ def _serialize(val: Any) -> JSON:
     return val
 
 
-class SerializableAttrs(GenericSerializable[T]):
+# TODO remove Generic[T] backwards compatibility in v0.10.0
+class SerializableAttrs(AbstractSerializable, Generic[T]):
     """
     An abstract :class:`Serializable` that assumes the subclass is an attrs dataclass.
 
@@ -283,17 +341,17 @@ class SerializableAttrs(GenericSerializable[T]):
         >>> from attr import dataclass
         >>> from mautrix.types import SerializableAttrs
         >>> @dataclass
-        ... class Foo(SerializableAttrs['Foo']):
+        ... class Foo(SerializableAttrs):
         ...     index: int
         ...     field: Optional[str] = None
     """
-    unrecognized_: Optional[JSON]
+    unrecognized_: Dict[str, JSON]
 
     def __init__(self):
         self.unrecognized_ = {}
 
     @classmethod
-    def deserialize(cls, data: JSON) -> T:
+    def deserialize(cls: Type[SerializableSubtype], data: JSON) -> SerializableSubtype:
         return _dict_to_attrs(cls, data)
 
     def serialize(self) -> JSON:
@@ -322,6 +380,4 @@ class SerializableAttrs(GenericSerializable[T]):
             try:
                 self.unrecognized_[item] = value
             except AttributeError:
-                self.unrecognized_ = {
-                    item: value,
-                }
+                self.unrecognized_ = {item: value}
